@@ -5,6 +5,7 @@ import tornado.web
 from tornado.util import ObjectDict
 
 from tornado.web import _UIModuleNamespace
+from tornado.escape import xhtml_escape, url_escape
 
 import functools
 import inspect
@@ -32,7 +33,7 @@ import re
 
 
 from tornado.web import HTTPError
-from tornado.escape import json_encode
+from tornadoez.escape import json_encode
 
 
 def api_public(method):
@@ -248,7 +249,7 @@ class RequestHandler(tornado.web.RequestHandler):
 
         self.api_messages = self.application.settings.get('api_messages', {})
 
-        self.app_version = self.application.settings.get('version',None)
+        self.app_version = self.application.settings.get('version', None)
 
         # ez-hack-end
 
@@ -302,7 +303,7 @@ class RequestHandler(tornado.web.RequestHandler):
             'cdn': self.cdn,
             'hacking_ie': self.hacking_ie,
             'debug': int(self.debug),
-            'app_version':self.app_version
+            'app_version': self.app_version
         })
 
         return namespace
@@ -338,10 +339,55 @@ class RequestHandler(tornado.web.RequestHandler):
 
     def compute_etag(self):
 
-        self.set_header('Server','Next')
+        self.set_header('Server', 'Next')
         return None
 
 
+    def post_redirect(self, url, msg, data, breads_title=[], breads_url=[], rec_title=[], rec_url=[], *args, **kwargs):
+        """
+        don't use get to set argument
+        :param url:
+        :param data:
+        :return:
+        """
+
+        # 基于html的方式很容易被攻击者伪造
+        # data_str = ''
+        #
+        # for k, v in data.items():
+        # if isinstance(v, list):
+        # for vv in v:
+        # data_str += k + '[]=' + xhtml_escape(vv) + '&'
+        # else:
+        # data_str += k + '=' + xhtml_escape(v) + '&'
+        # pass
+        #
+        # data_str.strip('&')
+        #
+        # if url.find('?') == -1:
+        # url += '?'
+        # else:
+        # url += '&'
+        #
+        # redirect_url = url + data_str
+
+
+        for k, v in kwargs.items():
+            if isinstance(v, list):
+                self.set_cookie('rt_' + k, url_escape('|'.join(v)))
+            else:
+                self.set_cookie('rt_' + k, url_escape(v))
+            pass
+
+        self.set_cookie('rt_rec_title', url_escape('|'.join(rec_title)))
+        self.set_cookie('rt_rec_url', url_escape('|'.join(rec_url)))
+        self.set_cookie('rt_breads_title', url_escape('|'.join(breads_title)))
+        self.set_cookie('rt_breads_url', url_escape('|'.join(breads_url)))
+        self.set_cookie('rt_msg', url_escape(msg))
+        self.redirect(url)
+        pass
+
+
     @detect_browser
     def render(self, template_name, **kwargs):
         template_name = template_name.format(self.browser_type)
